;************************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
;************************************************

begin

;**************   READ IN FILES   ***************
 f = addfile("data/cropFrac_Lmon_MPI-ESM-LR_CELUrcp45_r1i1p1_200601-210012_yearmean_global_area.nc","r")
 f_ctrl  = addfile("data/cropFrac_Lmon_MPI-ESM-LR_esmrcp85_r1i1p1_200601-210012_yearmean_global_area.nc","r")
 f_pas = addfile("data/pastureFrac_Lmon_MPI-ESM-LR_CELUrcp45_r1i1p1_200601-210012_yearmean_global_area.nc","r")
 f_pas_ctrl  = addfile("data/pastureFrac_Lmon_MPI-ESM-LR_esmrcp85_r1i1p1_200601-210012_yearmean_global_area.nc","r")
 f_tree = addfile("data/treeFrac_Lmon_MPI-ESM-LR_CELUrcp45_r1i1p1_200601-210012_yearmean_global_area.nc","r")
 f_tree_ctrl  = addfile("data/treeFrac_Lmon_MPI-ESM-LR_esmrcp85_r1i1p1_200601-210012_yearmean_global_area.nc","r")

; ************ READ IN VARIABLES  ***************

 temp_CE=f->cropFrac(:,0,0)
 temp_ctrl=f_ctrl->cropFrac(:,0,0)
 
 temp_pas_CE=f_pas->pastureFrac(:,0,0)
 temp_pas_ctrl=f_pas_ctrl->pastureFrac(:,0,0)

 temp_CE   = temp_CE + temp_pas_CE
 temp_ctrl = temp_ctrl + temp_pas_ctrl
 
 temp_tree_CE=f_tree->treeFrac(:,0,0)
 temp_tree_ctrl=f_tree_ctrl->treeFrac(:,0,0)

 time=f_ctrl->time

 temp = new((/4,dimsizes(time)/),typeof(temp_ctrl))
 temp(0,:) = temp_ctrl  /100 / 10^6 / 10^6 ; div by 100 to get rid of %, div by 10^6 to go from m^2 to km^2, another 10^6 to get mio
 temp(1,:) = temp_CE    /100 / 10^6 / 10^6  
 temp(2,:) = temp_tree_ctrl/100 / 10^6 / 10^6 
 temp(3,:) = temp_tree_CE/100 / 10^6 / 10^6
 
 utc_d = cd_calendar(time,0)
 years=utc_d(:,0)

;**********  OPEN GRAPHICS WORKSTATION *********
 wks_type = "eps"
 wks = gsn_open_wks(wks_type,"Figure1A")
;**********  GENERAL PLOT SETTINGS  ************
 xyres                 = True         ; xy plot mods desired
 xyres@vpHeightF       = 0.55             
 xyres@vpWidthF        = 0.75
 xyres@xyLineColors = (/"black","blue","black","blue"/)
 xyres@xyLineThicknesses = (/3.,3.,3.,3./)
 xyres@xyDashPatterns=(/0,0,1,1/)
 xyres@tiMainString     = "Global area / mio km~S~2"  
 xyres@tiYAxisOn = False
 xyres@tiMainFontHeightF = 0.031
 xyres@tmXBLabelFontHeightF  = 0.028
 xyres@tmYLLabelFontHeightF  = 0.028
 xyres@pmLegendDisplayMode    = "Always" 
 xyres@pmLegendSide           = "Top"               ; Change location of 
 xyres@pmLegendParallelPosF   = .23                  ; move units right
 xyres@pmLegendOrthogonalPosF = -0.44                ; move units down
 xyres@pmLegendWidthF         = 0.1                ; Change width and
 xyres@pmLegendHeightF        = 0.15                ; height of legend.
 xyres@lgPerimOn              = False               ; turn off box around
 xyres@lgLabelFontHeightF     = .024                 ; label font height
 xyres@xyExplicitLegendLabels = (/"  REF agriculture","  FOR agriculture","  REF forest","  FOR forest"/)
 xyres@lgItemOrder  = (/ 3,2,1,0 /)   ; Reorder the legends
 plot= gsn_csm_xy(wks,years,temp,xyres)
 
end
