;************************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
;************************************************

begin

;**************   READ IN FILES   ***************
 f = addfile("data/treeFrac_Lmon_MPI-ESM-LR_CELUrcp45_r1i1p1_2100_yearmean.nc","r")
 f_ctrl  = addfile("data/treeFrac_Lmon_MPI-ESM-LR_esmrcp85_r1i1p1_2100_yearmean.nc","r")
 f_hist  = addfile("data/treeFrac_Lmon_MPI-ESM-LR_esmHistorical_r1i1p1_2005_yearmean.nc","r")

; ************ READ IN VARIABLES  ***************

 temp_CE=f->treeFrac(0,:,:)
 temp_ctrl=f_ctrl->treeFrac(0,:,:)
 temp_hist=f_hist->treeFrac(0,:,:)
 
 temp_CE   = ( temp_CE - temp_hist ) / 100.
 temp_ctrl = ( temp_ctrl - temp_hist ) / 100.
 
;**********  OPEN GRAPHICS WORKSTATION *********
 wks_type = "eps"
 wks = gsn_open_wks(wks_type,"Figure1B")
 gsn_define_colormap(wks,"BlWhRe")     
;**********  GENERAL PLOT SETTINGS  ************

 plot = new(3,graphic)  
 res                 = True
 res@gsnDraw             = False           ; don't draw
 res@gsnFrame            = False           ; don't advance frame
 res@cnInfoLabelOn       = False           ; turn off cn info label
 res@cnFillOn            = True            ; turn on color
 res@cnFillMode          = "CellFill"
 res@gsnSpreadColors     = True            ; spread out color table 
 res@cnLinesOn           = False
 res@cnLineLabelsOn      = False 
 res@lbLabelBarOn        = False           ; t; res@gsnMaximize       = True
 res@mpProjection = "CylindricalEquidistant"
 res@mpLimitMode = "LatLon"
 res@mpMinLatF = -60.
 res@mpMaxLatF = 84.
 res@mpPerimOn = False 
 res@mpPerimDrawOrder = "PostDraw"
 res@tmXBLabelsOn = False 
 res@tmXBOn = False
 res@tmYLLabelsOn = False
 res@tmYLOn = False
 res@tmXTOn = False
 res@tmYROn = False
 res@cnLevelSelectionMode = "ExplicitLevels"    			; set explicit contour levels
 res@cnLevels    = (/ -.5,-.2,-.1,-.05,-.02,-.01,.01,.02,.05,.1,.2,.5/)	; set levels
 res@gsnLeftStringFontHeightF = 0.022
 res@gsnRightString  = ""
 res@gsnLeftString  = "FOR (2100) - HIST (2005)"
 plot(0) = gsn_csm_contour_map(wks,temp_CE,res)
 res@gsnLeftString  = "REF (2100) - HIST (2005)"
 plot(1) = gsn_csm_contour_map(wks,temp_ctrl,res)
 temp_CE = temp_CE - temp_ctrl
 res@gsnLeftString  = "FOR (2100) - REF (2100)"
 plot(2) = gsn_csm_contour_map(wks,temp_CE,res)
 
;************************************************
; create panel
;************************************************
  resP                     = True                ; modify the panel plot
  resP@txString            = "Forest cover fraction / %"
  resP@txFontHeightF = 0.022
  resP@gsnPanelLabelBar    = True                ; add common colorbar
  resP@lbLabelFontHeightF  = 0.018               ; make labels smaller
  resP@lbLabelStrings = (/"-50","-20","-10","-5","-2","-1","1","2","5","10","20","50"/)
  gsn_panel(wks,plot,(/3,1/),resP)               ; now draw as one plot
 
end
