;************************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
;************************************************

begin

;**************   READ IN FILES   ***************
 fSoil = addfile("data/cSoil_Lmon_MPI-ESM-LR_CELUrcp45_r1i1p1_200601-210012_yearmean_globsum.nc","r")
 fSoil_ctrl  = addfile("data/cSoil_Lmon_MPI-ESM-LR_esmrcp85_r1i1p1_200601-210012_yearmean_globsum.nc","r")
 fLitter = addfile("data/cLitter_Lmon_MPI-ESM-LR_CELUrcp45_r1i1p1_200601-210012_yearmean_globsum.nc","r")
 fLitter_ctrl  = addfile("data/cLitter_Lmon_MPI-ESM-LR_esmrcp85_r1i1p1_200601-210012_yearmean_globsum.nc","r")
 fVeg = addfile("data/cVeg_Lmon_MPI-ESM-LR_CELUrcp45_r1i1p1_200601-210012_yearmean_globsum.nc","r")
 fVeg_ctrl  = addfile("data/cVeg_Lmon_MPI-ESM-LR_esmrcp85_r1i1p1_200601-210012_yearmean_globsum.nc","r")
 fCbalone_esmrcp85 = addfile("data/Cbalone.2006-2100_esmrcp85_boxCpoolstotal_globsum.nc","r")
 fCbalone_WHrcp85 = addfile("data/Cbalone.2006-2100_WHrcp85_boxCpoolstotal_globsum.nc","r")
 fCbalone_pres   = addfile("data/Cbalone.2006-2100_present_boxCpoolstotal_globsum.nc","r")

; ************ READ IN VARIABLES  ***************

 cSoil_CE=fSoil->cSoil(:,0,0)
 cSoil_ctrl=fSoil_ctrl->cSoil(:,0,0)
 cLitter_CE=fLitter->cLitter(:,0,0)
 cLitter_ctrl=fLitter_ctrl->cLitter(:,0,0)
 cVeg_CE=fVeg->cVeg(:,0,0)
 cVeg_ctrl=fVeg_ctrl->cVeg(:,0,0)
 cbal_esmrcp85         = fCbalone_esmrcp85->box_Cpools_total(:,0,0)
 cbal_WHrcp85          = fCbalone_WHrcp85->box_Cpools_total(:,0,0)
 cbal_pres             = fCbalone_pres->box_Cpools_total(:,0,0)

 time=fSoil_ctrl->time

 ctot = new((/5,dimsizes(time)/),typeof(cSoil_ctrl))
 ctot(0,:) = ( cSoil_ctrl + cLitter_ctrl + cVeg_ctrl) / 10^12 ; kg -> Gt (=Pg)
 ctot(1,:) = ( cSoil_CE + cLitter_CE + cVeg_CE) / 10^12
 ctot(2,:) = dble2flt(cbal_esmrcp85 * 12 / 10^15)   ; mol -> Gt
 ctot(3,:) = dble2flt(cbal_WHrcp85 * 12 / 10^15)   ; mol -> Gt
 ctot(4,:) = dble2flt(cbal_pres * 12 / 10^15)

; differences:

 ctot_diff = new((/4,dimsizes(time)/),typeof(cSoil_ctrl))
 ctot_diff(0,:) = ctot(1,:) - ctot(0,:)
 ctot_diff(1,:) = ctot(4,:) - ctot(0,:)
 ctot_diff(2,:) = ctot(2,:) - ctot(0,:)
 ctot_diff(3,:) = ctot(3,:) - ctot(0,:)

 utc_d = cd_calendar(time,0)
 years=utc_d(:,0)
 
;**********  OPEN GRAPHICS WORKSTATION *********
 wks_type = "eps"
 wks = gsn_open_wks(wks_type,"Figure1C")
;**********  GENERAL PLOT SETTINGS  ************
 
 xyres                 = True         ; xy plot mods desired
 xyres@vpHeightF       = 0.55             
 xyres@vpWidthF        = 0.75
 xyres@xyLineColors = (/"blue","red","red","red"/)
 xyres@xyLineThicknesses = (/4.,3.,3.,3./)
 xyres@xyDashPatterns= (/0,0,1,2/)
 xyres@tiMainString     = "Global terrestrial C content / Gt"  
 xyres@tiMainFontHeightF = 0.031
 xyres@tiYAxisOn = False
 xyres@tmXBLabelFontHeightF  = 0.028
 xyres@tmYLLabelFontHeightF  = 0.028
 xyres@pmLegendDisplayMode    = "Always" 
 xyres@pmLegendSide           = "Top"               ; Change location of 
 xyres@pmLegendParallelPosF   = .3                  ; move units right
 xyres@pmLegendOrthogonalPosF = -0.5                ; move units down
 xyres@pmLegendWidthF         = 0.1                ; Change width and
 xyres@pmLegendHeightF        = 0.15                ; height of legend.
 xyres@lgPerimOn              = False               ; turn off box around
 xyres@lgLabelFontHeightF     = .024                 ; label font height
 xyres@xyExplicitLegendLabels = (/"  FOR - REF","  FORPRES - REF","  FORREF - REF","  FORWH - REF"/)
 xyres@lgItemOrder  = (/ 3,2,1,0 /)   ; Reorder the legends

 plot= gsn_csm_xy(wks,years,ctot_diff,xyres)
 
 
end
