;************************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
;************************************************

begin

;**************   READ IN FILES   ***************
 f = addfile("data/co2_Amon_MPI-ESM-LR_CELUrcp45_r1i1p1_200601-210012_yearmean_globmean.nc","r")
 f_ctrl  = addfile("data/co2_Amon_MPI-ESM-LR_esmrcp85_r1i1p1_200601-210012_yearmean_globmean.nc","r")
 f_rcp45 = addfile("data/greenhouse_rcp45_2006-2100.nc","r")

; ************ READ IN VARIABLES  ***************

 co2_CE=f->co2(:,:,0,0)
 co2_ctrl=f_ctrl->co2(:,:,0,0)
 co2_rcp45 = f_rcp45->CO2

 time=f_ctrl->time

 lev=0

 co2 = new((/3,dimsizes(time)/),typeof(co2_ctrl))
 co2(1,:) = co2_ctrl(:,lev)
 co2(2,:) = co2_CE(:,lev)
 co2(0,:) = dble2flt(co2_rcp45)
 
 difference = co2_ctrl(dimsizes(time)-1,lev) - co2_CE(dimsizes(time)-1,lev)
 differencercp45 = co2_ctrl(dimsizes(time)-1,lev) - dble2flt(co2_rcp45(dimsizes(time)-1))

 utc_d = cd_calendar(time,0)
 years=utc_d(:,0)
 
;**********  OPEN GRAPHICS WORKSTATION *********
 wks_type = "eps"
 wks = gsn_open_wks(wks_type,"Figure2A")
;**********  GENERAL PLOT SETTINGS  ************
 
 xyres                 = True         ; xy plot mods desired
 xyres@vpHeightF       = 0.55             
 xyres@vpWidthF        = 0.75
 xyres@xyMonoDashPattern  = True
 xyres@xyLineColors = (/"green","black","blue"/)
 xyres@xyLineThicknesses = (/4.,4.,4./)
 xyres@tiMainString     = "Atmospheric CO~B~2~N~ mole fraction / ppm"  
 xyres@tiMainFontHeightF = 0.031
 xyres@tiYAxisOn = False
 xyres@trYMinF  = 380.0
 xyres@tmXBLabelFontHeightF = 0.028
 xyres@tmYLLabelFontHeightF = 0.028
 xyres@pmLegendDisplayMode    = "Always" 
 xyres@pmLegendSide           = "Top"               ; Change location of 
 xyres@pmLegendParallelPosF   = .32                  ; move units right
 xyres@pmLegendOrthogonalPosF = -0.6                ; move units down
 xyres@pmLegendWidthF         = 0.1                ; Change width and
 xyres@lgPerimOn              = False               ; turn off box around
 xyres@lgLabelFontHeightF     = .024                 ; label font height
 xyres@xyExplicitLegendLabels = (/"  rcp45","  REF","  FOR"/)
 xyres@lgItemOrder  = (/ 0,2,1 /)   ; Reorder the legends
 plot= gsn_csm_xy(wks,years,co2,xyres)
 
end
