;************************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
;************************************************

begin

;**************   READ IN FILES   ***************
 f = addfile("data/tasmin_day_MPI-ESM-LR_CELUrcp45_r1i1p1_2081-2100_yearmin_timmean.nc","r")
 f_ctrl  = addfile("data/tasmin_day_MPI-ESM-LR_esmrcp85_r1i1p1_2081-2100_yearmin_timmean.nc","r")
 f_std = addfile("data/tasmin_day_MPI-ESM-LR_CELUrcp45_r1i1p1_2081-2100_yearmin_timstd.nc","r")
 f_std_ctrl  = addfile("data/tasmin_day_MPI-ESM-LR_esmrcp85_r1i1p1_2081-2100_yearmin_timstd.nc","r")
 f_timser = addfile("data/tasmin_day_MPI-ESM-LR_CELUrcp45_r1i1p1_2081-2100_yearmin.nc","r")
 f_timser_ctrl = addfile("data/tasmin_day_MPI-ESM-LR_esmrcp85_r1i1p1_2081-2100_yearmin.nc","r")

; ************ READ IN VARIABLES  ***************
 
 temp_CE=f->tasmin(0,:,:)
 temp_ctrl=f_ctrl->tasmin(0,:,:)
 temp_std_CE=f_std->tasmin(0,:,:)
 temp_std_ctrl=f_std_ctrl->tasmin(0,:,:)
 temp_timser_CE=f_timser->tasmin(:,:,:)
 temp_timser_ctrl=f_timser_ctrl->tasmin(:,:,:)

 prob_corr= f_std_ctrl->tasmin(0,:,:)

;----------------------------------------
; calc ttest
;----------------------------------------

 siglev=0.05
 neqv_CE = equiv_sample_size(temp_timser_CE(lat|:,lon|:,time|:),siglev,0)
 neqv_ctrl = equiv_sample_size(temp_timser_ctrl(lat|:,lon|:,time|:),siglev,0)
 prob_corr = (/ttest(temp_CE,temp_std_CE^2,neqv_CE, temp_ctrl,temp_std_ctrl^2,neqv_ctrl, iflag, False) /)

 temp_CE  = temp_CE - temp_ctrl

;**********  OPEN GRAPHICS WORKSTATION *********
 wks_type = "eps"
 wks = gsn_open_wks(wks_type,"FigureS3B")
 gsn_define_colormap(wks,"BlWhRe")  
;**********  GENERAL PLOT SETTINGS  ************

 res                 = True
 res@gsnDraw             = False           ; don't draw
 res@gsnFrame            = False           ; don't advance frame
 res@cnInfoLabelOn       = False           ; turn off cn info label
 res@cnFillOn            = True            ; turn on color
 res@cnFillMode          = "CellFill"
 res@gsnSpreadColors     = True            ; spread out color table 
 res@cnLinesOn           = False
 res@cnLineLabelsOn      = False 
 res@lbLabelBarOn        = True         
 res@gsnMaximize         = True
 res@mpProjection = "CylindricalEquidistant"
 res@mpLimitMode = "LatLon"
 res@mpMinLatF = -88.
 res@mpMaxLatF = 88.
 res@mpPerimDrawOrder = "PostDraw"
 res@mpFillOn = False
 res@tmXBLabelsOn = False 
 res@tmXBOn = False
 res@tmYLLabelsOn = False
 res@tmYLOn = False
 res@tmXTOn = False
 res@tmYROn = False
 res@cnLevelSelectionMode = "ExplicitLevels"    			; set explicit contour levels
 res@cnLevels    = (/ -3.0,-2.75,-2.5,-2.25,-2.0,-1.75,-1.5,-1.25,-1.,-0.75,-0.5,-0.25,0.25,0.5,0.75,1.,1.25,1.5,1.75,2.,2.25,2.5,2.75,3.0/)
 res@cnExplicitLabelBarLabelsOn = True 
 res@lbLabelAutoStride = False
 res@lbLabelStrings = (/"-3.0","","-2.5","","-2.0","","-1.5","","-1.0","","-0.5","","","0.5","","1.0","","1.5","","2.0","","2.5","","3.0"/)
 res@lbLabelFontHeightF  = 0.025   
 res@pmLabelBarWidthF = 0.8
 res@pmLabelBarOrthogonalPosF = 0.0
 res@gsnRightString  = ""
 res@gsnLeftString  = ""
 res@tiMainFontHeightF = 0.028
 res@tiMainString = "Coldest night SAT / K"
 res@tiMainFont = 21

 plot1 = gsn_csm_contour_map_ce(wks,temp_CE,res)

 res_sign                 = True
 res_sign@cnInfoLabelOn   = False          ; no info label
 res_sign@cnLineLabelsOn  = False 
 res_sign@cnFillOn        = False
 res_sign@cnLinesOn       = False         ; Turn lines back on
 res_sign@gsnDraw = False                 ; do not draw the plot
 res_sign@gsnFrame = False                ; do not advance the frame
 res_sign@gsnLeftString  = "FOR (2081-2100) - REF (2081-2100)"
 res_sign@gsnRightString  = ""
 res_sign@gsnLeftStringFontHeightF = 0.035
 res_sign@gsnAddCyclic = True

  opt = True
  opt@gsnShadeFillType = "pattern"      ; pattern fill
  opt@gsnShadeMid  = 3

; Overlay PLot: significance

 plot2 = gsn_csm_contour(wks,prob_corr,res_sign)
 plot2 = gsn_contour_shade(plot2,.05,.1,opt)  

 overlay(plot1,plot2)
 draw(plot1)
 frame(wks)            
end
